"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const ConfigRepository_1 = require("../config/ConfigRepository");
const Resolver_1 = require("../services/Resolver");
const Logger_1 = require("../helpers/Logger");
const File_1 = require("../helpers/File");
const chalk = require('chalk');
class BaseCommand extends command_1.Command {
    constructor(argv, config) {
        super(argv, config);
        this.warnings = [];
        this.configRepository = new ConfigRepository_1.default();
        this.logger = new Logger_1.default();
    }
    resolve() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.signature == null) {
                return;
            }
            const resolver = new Resolver_1.default(this.configRepository, this.signature);
            this.parser = yield resolver.resolveParser();
            this.decorators = yield resolver.resolveDecorators();
            this.factories = yield resolver.resolveFactories();
        });
    }
    loadFile(args) {
        return __awaiter(this, void 0, void 0, function* () {
            let file;
            try {
                file = new File_1.default(args.input);
            }
            catch (error) {
                this.logger.fail(`${args.input} is not a valid file.\n${error.message}`);
                this.exit(-1);
            }
            return file;
        });
    }
    parseSpec(file) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.spin('Parsing input file');
            let spec;
            try {
                yield this.resolve();
                spec = yield this.parser.execute(file.path());
            }
            catch (error) {
                this.logger.fail(error.message);
                process.exit(-1);
            }
            this.logger.succeed('Input file parsed');
            return spec;
        });
    }
    runFactories(specification) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                for (let i = 0; i < this.factories.length; i = i + 1) {
                    let warnings = yield this.factories[i].execute(specification, this.configRepository.get(`commands.${this.configKey}`));
                    warnings = warnings.map((warning) => {
                        return `${chalk.italic.cyan(this.factories[i].getName())} - ${warning}`;
                    });
                    this.warnings.push(...warnings);
                }
            }
            catch (error) {
                this.logger.fail(error.message);
                this.exit(-1);
            }
        });
    }
    runDecorators(specification) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                for (let i = 0; i < this.decorators.length; i = i + 1) {
                    let warnings = yield this.decorators[i].execute(specification, this.configRepository.get(`commands.${this.configKey}`));
                    warnings = warnings.map((warning) => {
                        return `${chalk.italic.cyan(this.decorators[i].getName())} - ${warning}`;
                    });
                    this.warnings.push(...warnings);
                }
            }
            catch (error) {
                this.logger.fail(`${error.message}
      Stack: ${error.stack}`);
                this.exit(-1);
            }
        });
    }
    printWarnings() {
        this.warnings.forEach((warning) => {
            this.logger.warn(warning);
        });
    }
}
exports.default = BaseCommand;
//# sourceMappingURL=BaseCommand.js.map