"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os = require('os');
const path = require('path');
const fs = require('fs-extra');
class File {
    constructor(filePath) {
        this.absolutePath = path.resolve(filePath);
        this.filePath = this.relativePath();
        this.segments = this.parse();
    }
    static find(file) {
        return new File(file);
    }
    size() {
        return fs.statSync(this.path()).size;
    }
    static exists(file) {
        return fs.existsSync(file);
    }
    delete() {
        if (fs.existsSync(this.path())) {
            fs.unlinkSync(this.path());
        }
    }
    name() {
        return this.segments.file;
    }
    nameWithoutExtension() {
        return this.segments.name;
    }
    extension() {
        return this.segments.ext;
    }
    path() {
        return this.absolutePath;
    }
    relativePath() {
        return path.relative(process.cwd(), this.path());
    }
    pathWithoutExtension() {
        return this.segments.pathWithoutExt;
    }
    base() {
        return this.segments.base;
    }
    isDirectory() {
        return this.segments.isDir;
    }
    isFile() {
        return this.segments.isFile;
    }
    write(body) {
        let contents = body;
        if (typeof body === 'object') {
            contents = JSON.stringify(body, null, 4);
        }
        contents = contents + os.EOL;
        fs.writeFileSync(this.absolutePath, contents);
        return this;
    }
    read() {
        return fs.readFileSync(this.path(), {
            encoding: 'utf-8',
        });
    }
    copyTo(destination) {
        fs.copySync(this.path(), destination);
        return this;
    }
    rename(to) {
        const toPath = path.join(this.base(), to);
        fs.renameSync(this.path(), toPath);
        return new File(toPath);
    }
    parse() {
        const parsed = path.parse(this.absolutePath);
        return {
            path: this.filePath,
            absolutePath: this.absolutePath,
            pathWithoutExt: path.join(parsed.dir, `${parsed.name}`),
            isDir: !parsed.ext && !parsed.name.endsWith('*'),
            isFile: !!parsed.ext,
            name: parsed.name,
            ext: parsed.ext,
            file: parsed.base,
            base: parsed.dir,
        };
    }
}
exports.default = File;
//# sourceMappingURL=File.js.map